Get pharmacogenetic guidelines for a list of compound names
Source:R/compound.R
api_compound_guideline.RdGet pharmacogenetic guidelines for a list of compound names
See also
api_login() to retrieve the login object.
R/compound.R
api_compound_guideline.RdGet pharmacogenetic guidelines for a list of compound names
api_login() to retrieve the login object.