Skip to contents

Get interactions for a list of Compounds

Usage

api_interaction_compound(creds, compounds, details = FALSE, doses = TRUE, text = FALSE)

Arguments

creds

A list containing the access token and host

compounds

A vector with the Compound names

details

A boolean indicating if detailed information should be returned

doses

A boolean indicating if doses should be returned

text

A boolean indicating if interaction text should be returned

Value

A data frame with the interactions

See also

api_login() to retrieve the login object.

Examples

if (FALSE) { # \dontrun{
creds <- api_login("https://api.example.com", "username", "password", "user")
api_interaction_compound(creds, c("Aspirin", "Paracetamol"), details = TRUE, text = TRUE)
} # }