Skip to contents

Sends a password reset token to the specified email address. This is a public endpoint that does not require authentication. Use api_user_confirm_password_reset() to set the new password with the received token.

Usage

api_user_request_password_reset(host, email)

Arguments

host

The API base URL.

email

The email address of the account to reset.

Value

A named list with the API response message.

See also

api_user_confirm_password_reset() to confirm the reset with the token.

Examples

if (FALSE) { # \dontrun{
api_user_request_password_reset("https://api.example.com", "user@example.com")
} # }