Get interactions for a list of PZNs
Usage
api_interaction_pzn(creds, pzns, details = FALSE, text = FALSE)
Arguments
- creds
A list containing the access token and host
- pzns
A vector with the PZNs
- details
A boolean indicating if detailed information should be returned
- text
A boolean indicating if interaction text should be returned
Value
A data frame with the interactions
Examples
if (FALSE) { # \dontrun{
creds <- api_login("https://api.example.com", "username", "password", "user")
api_interaction_pzn(creds, c("PZN1", "PZN2"), details = TRUE, text = TRUE)
} # }