Confirms an email change request using the token sent to the new address. The new email becomes active on the next login.
Arguments
- credentials
An
ApiCredentialsobject fromapi_login().- token
The confirmation token received by email.
See also
api_login() to retrieve credentials.
api_user_request_email_change() to initiate the email change.
Examples
if (FALSE) { # \dontrun{
creds <- api_login("https://api.example.com", "user@example.com", "password")
api_user_confirm_email_change(creds, "my_change_token")
} # }