Sets a new password using the reset token received by email after calling
api_user_request_password_reset(). This is a public endpoint that does
not require authentication.
See also
api_user_request_password_reset() to request the reset token.
Sets a new password using the reset token received by email after calling
api_user_request_password_reset(). This is a public endpoint that does
not require authentication.
api_user_request_password_reset() to request the reset token.