Sends a password reset token to the specified email address. This is a
public endpoint that does not require authentication. Use
api_user_confirm_password_reset() to set the new password with the received token.
See also
api_user_confirm_password_reset() to confirm the reset with the token.